<?php
/**
 *
 * WinsomeThemes Framework
 *
 * @author WinsomeThemes
 * @license Commercial License
 * @link http://www.winsomethemes.com
 * @copyright 2019 WinsomeThemes
 * @package wstFramework
 * @version 1.0.0
 *
 */
if ( ! defined( 'ABSPATH' ) ) exit( 'Access Denied.' );

class wst_enq_styles {
    
    public function __construct () {
        add_action( 'wp_enqueue_scripts', array( &$this , 'wst_enqueue_styles' ) );
    }
    
    public function wst_enqueue_styles() {
        $langcode = '';
        if ( class_exists( 'SitePress' ) ) {
            $langcode = '-'.ICL_LANGUAGE_CODE;
        } else if( class_exists( 'Polylang' ) ){
            $langcode = '-'. pll_current_language();
        }
        
        $bbp            = ( function_exists('is_bbpress') && is_bbpress() ) ? 'is_bbpress' : '';
        $buddy          = ( function_exists('is_buddypress') && is_buddypress() ) ? 'is_buddypress' : '';
        
        $url_handle     = 'wst_google_fonts';
        $variants       = ':100,200,300,400,500,600,700,900';        
        $body_font      = ( wst_theme_option( 'body_font' . $langcode ) )     ? str_replace( ' ', '+', wst_theme_option('body_font'.$langcode) ) . $variants        : "";
        $menu_font      = ( wst_theme_option( 'menu_font' . $langcode ) )     ? str_replace( ' ', '+', wst_theme_option('menu_font'.$langcode) ) . $variants        : "";
        $headings_font  = ( wst_theme_option( 'headings_font' . $langcode ) ) ? str_replace( ' ', '+', wst_theme_option('headings_font'.$langcode) ) . $variants    : "";
        $logo_font      = ( wst_theme_option( 'logo_font' . $langcode ) )     ? str_replace( ' ', '+', wst_theme_option('logo_font'.$langcode) ) . $variants        : "";
        $slogan_font    = ( wst_theme_option( 'slogan_font' . $langcode ) )   ? str_replace( ' ', '+', wst_theme_option('slogan_font'.$langcode) ) . $variants      : "";
        $title_font     = ( wst_theme_option( 'title_font' . $langcode ) )    ? str_replace( ' ', '+', wst_theme_option('title_font'.$langcode) ) . $variants       : "";
        
        $font_families  = array( $body_font, $menu_font, $headings_font, $logo_font, $slogan_font, $title_font );
        $font_families  = array_unique( $font_families );
        
        $fams = str_replace( '||', '|',implode( '|', $font_families ));
        
        if ( ! empty( $font_families ) ){    
            $wst_query_args = array(
                'family' => $fams,
                'subset' => 'latin,latin-ext',
            );
                    
            $request_url = add_query_arg( $wst_query_args, "//fonts.googleapis.com/css" );    
            wp_deregister_style( $url_handle );
            
            wp_register_style( $url_handle, $request_url, null, null );
            wp_enqueue_style( $url_handle );
            
        }
        
        wp_enqueue_style( 'wst-rest-style',         wst_thm_uri . '/assets/css/vendor/rest.css' );
        wp_enqueue_style( 'streamline',             wst_thm_uri . '/assets/css/vendor/streamline.css' );
        wp_enqueue_style( 'font-awesome',           wst_thm_uri . '/assets/css/vendor/font.awesome.css' );
                
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) == "1" ){
            wp_enqueue_script( 'comment-reply' );
        } 
        
        wp_register_script( 'modernizr',            wst_thm_uri . '/assets/js/vendor/modernizr.js',                  array('jquery'), null, true);
        wp_register_script( 'scroll-to-id',         wst_thm_uri . '/assets/js/vendor/scroll.to.id.js',               array('jquery'), null, true);
        wp_register_script( 'jquery-enllax',        wst_thm_uri . '/assets/js/vendor/jquery.enllax.min.js',          array('jquery'), null, true);
        
        if( $bbp ){
            wp_enqueue_style( 'wst-bbpress',        wst_thm_uri . '/assets/css/plugins/bbpress.css' );
        }
        
        if( $buddy ) {
            wp_enqueue_style( 'wst-buddy',          wst_thm_uri . '/assets/css/plugins/buddypress.css' );
        }
        
        if( function_exists('is_woocommerce') ){
            wp_enqueue_style( 'wst-woo',            wst_thm_uri . '/woocommerce/assets/woo.css' );
            wp_enqueue_style( 'magnific-popup',     wst_thm_uri . '/woocommerce/assets/magnific-popup.css' );
            wp_enqueue_script( 'magnific-popup',    wst_thm_uri . '/woocommerce/assets/magnific.popup.js',          array('jquery'), null, true);
            wp_enqueue_script( 'wst-woo',           wst_thm_uri . '/woocommerce/assets/woo.js',                     array('jquery'), null, true );
        }
        
        wp_enqueue_style( 'wst-main-style',         wst_thm_uri . '/assets/css/style.css' );

        wp_add_inline_style( 'wst-main-style',      wst_custom_css() );
                
        wp_register_script( 'jquery-slurve',        wst_thm_uri . '/assets/js/vendor/jquery.slurve.js',    array('jquery'), null, true);
        wp_register_script( 'wst-main-script',      wst_thm_uri . '/assets/js/script.js',                  array('jquery'), null, true);
        
        wp_enqueue_script('modernizr');
        wp_enqueue_script('scroll-to-id');
        
        $meta_particles = get_post_meta(wst_page_id(), 'meta_page_particles',true);
        $them_particles = wst_theme_option( 'theme_particles' );
        $partcls        = ( $meta_particles == '' ) ? $them_particles : $meta_particles;

        if ( $partcls == '1' ) {
            wp_enqueue_script('jquery-enllax');
        }

        if( wst_theme_option( 'body_smooth' ) == 1 ){
            wp_enqueue_script( 'wst-smooth-scroll',   wst_thm_uri . '/assets/js/vendor/smooth.scroll.js',          array('jquery'), null, true); 
        }
        wp_enqueue_script('jquery-slurve');
        wp_enqueue_script('wst-main-script');
          
    }
    
}
new wst_enq_styles();