<?php
/**
 *
 * WinsomeThemes Framework
 *
 * @author WinsomeThemes
 * @license Commercial License
 * @link http://www.winsomethemes.com
 * @copyright 2019 WinsomeThemes
 * @package wstFramework
 * @version 1.0.0
 *
 */
if ( ! defined( 'ABSPATH' ) ) exit( 'Access Denied.' );

// Add theme support..
if( ! function_exists( 'wst_after_setup_theme' ) ) {
    function wst_after_setup_theme() {
        
        if ( function_exists( 'add_theme_support' ) ) {
            
            add_theme_support( 'post-thumbnails' );
            add_theme_support('automatic-feed-links');
            
            // add theme support for wp 4.1 and higher.
            add_theme_support( "title-tag" );
            
            add_theme_support( 'html5', array(
                'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
            ));
            add_theme_support( 'post-formats', array(
                'aside', 'image', 'video', 'audio', 'quote', 'link', 'gallery', 'status', 'chat',
            ));

            add_theme_support( 'custom-background', apply_filters( 'it_custom_background_args', array(
                'default-color' => 'f5f5f5',
            )));

            // Add support for featured content.
            add_theme_support( 'featured-content', array(
                'featured_content_filter' => 'wst_get_featured_posts',
                'max_posts' => 6,
            ));
            add_theme_support('custom-header');
        }
        
        if ( ! isset( $content_width ) ) $content_width = wst_theme_option( 'main_width' );
        
        add_editor_style();
        
        define( 'wst_HEADER_IMAGE_WIDTH', apply_filters( 'wst_header_image_width', 1170 ) );
        define( 'wst_HEADER_IMAGE_HEIGHT', apply_filters( 'wst_header_image_height', 400 ) );
        
        load_theme_textdomain( 'qonspt' , wst_thm_dir . '/languages' );
                            
    }
    add_action( 'after_setup_theme', 'wst_after_setup_theme' );
}

if ( ! function_exists( 'wst_add_image_sizes' ) ) {
    function wst_add_image_sizes() {
        add_image_size( 'wst-image-500-500', 500, 500, true );
    }
    add_action( 'init', 'wst_add_image_sizes' );
}

if ( ! function_exists( 'wst_language_selector_flags' ) ) {
    function wst_language_selector_flags(){
        $languages = icl_get_languages('skip_missing=0&orderby=code');
        if(!empty($languages)){
            foreach($languages as $l){
                echo '<span class="lng_select">';
                    if(!$l['active']) echo '<a href="'.esc_url($l['url']).'">';
                    echo '<img src="'.esc_url( $l['country_flag_url'] ).'" height="12" alt="'.esc_attr( $l['language_code'] ).'" width="18" />';
                    if(!$l['active']) echo '</a>';
                echo '</span>';
            }
        }
    }
}

// Get theme image sizes..
if ( ! function_exists( 'wst_get_image_sizes' ) ) {
    function wst_get_image_sizes() {
        global $_wp_additional_image_sizes;
        $wst_image_sizes = get_intermediate_image_sizes(); 
        $wst_imgs = array();
        foreach ( $wst_image_sizes as $size ) {
            $wst_imgs[$size] = $size;
        }
               
        return $wst_imgs;
    }    
}

// Add media to editor.. 
if ( ! function_exists( 'wst_media_editor' ) ){
    function wst_media_editor($html, $send_id, $attachment ){
        $post = get_post($send_id);
        $html .= '<media>'.$post->guid.'</media>';
        return $html;
    }
    add_filter('media_send_to_editor', 'wst_media_editor', 1, 3);
}

// Select menus..
if ( ! function_exists( 'wst_site_menu' ) ){
    function wst_site_menu(){
        $selmenu = array();
        $wst_menus = get_registered_nav_menus();
        foreach($wst_menus as $location => $description){
            $selmenu[$location] = $description;
        }
        $smenu = array('' => '-- '.esc_html__('Select Menu','qonspt').' --');
        $wst_menu = $smenu + $selmenu;
        return $wst_menu;
    }    
}

if ( ! function_exists('wst_site_menus') ) {
    function wst_site_menus()
    {

        $all_menus = wp_get_nav_menus();
        $menus = [];
        if($all_menus){
            foreach($all_menus as $menu){
                $menus[$menu->slug] = $menu->name;
            }
        }
        $blank_menu = ['' => '-- '.esc_html__('Select','qonspt').' --'];
        $crust_menu = $blank_menu + $menus;
        return $crust_menu;
    }

}

// get current page ID..
if ( ! function_exists( 'wst_page_id' ) ){
    function wst_page_id(){
        global $post;
        $pageID = '';
        if( ( get_option( 'show_on_front' ) && get_option( 'page_for_posts' ) && is_home() )) {
            $pageID = get_option('page_for_posts');
        } else {
            if(isset($post) && !is_search()) {
                $pageID = $post->ID;
            }
            if(class_exists('Woocommerce')) {
                if(is_shop() || is_tax('product_cat') || is_tax('product_tag')) {
                    $pageID = get_option('woocommerce_shop_page_id');
                }
            }
        }
        return $pageID;
    }
}

// Page Loader..
if ( ! function_exists( 'wst_loader' ) ) {
    function wst_loader(){
        $loader         = wst_theme_option('page_loader');
        $pr_ld          = wst_theme_option('page_loader_style');
        $loadtxt        = wst_theme_option( 'loadertext' );
        $m_main_color   = esc_html(get_post_meta( wst_page_id() , 'meta_body_main_color' , true));
        $hexStr         = ( $m_main_color != '' ) ?  $m_main_color : esc_html(wst_theme_option( "skin_color" ));
        $load_id        = preg_replace( '/[^\d]/', '', wst_theme_option('loaderimage') );
        $load_src       = wp_get_attachment_image_src( $load_id,'full' );
        
        if ($loader == '1'){
            
            echo '<style type="text/css">';
            if ( wst_theme_option('loader_bar_bg') ) {
                if ( $pr_ld == '1' ){
                echo ".wst-loader-".$pr_ld." {
                        background-color: ".wst_theme_option('loader_bar_bg').";
                    }";
                } else if ( $pr_ld == '2' ){
                    echo ".spinningSquaresG {
                        --background-color: ".wst_theme_option('loader_bar_bg').";
                        background-color: ".wst_theme_option('loader_bar_bg').";
                    }";
                }
            }
            
            if ( wst_theme_option('loader_bar_forecolor') ) {
                if ( $pr_ld == '1' ){
                    echo ".wst-loader-".$pr_ld.":before {
                        background-color: ".wst_theme_option('loader_bar_forecolor').";
                    }";    
                } else if ( $pr_ld == '2' ){
                    echo ".spinningSquaresG {
                        --forground-color: ".wst_theme_option('loader_bar_forecolor').";
                        
                    }";    
                } else if ( $pr_ld == '3' ){
                    echo ".cssload-dot {
                        background-color: ".wst_theme_option('loader_bar_forecolor').";
                    }";    
                }
                            
            }
            
            if ( wst_theme_option('loader_text_color') ) {

                echo ".wst-loader-text {
                    color: ".wst_theme_option('loader_text_color').";
                }";
                            
            }
            echo '</style>';
                         
            echo '<div class="page-loader">';
                echo '<div class="inner_loader">';
                    
                    if( $pr_ld == 'img') {
                        echo '<div class="loader_img"><img alt="'.esc_attr__('Loading','qonspt').'" src="'.esc_url($load_src[0]).'"></div>';
                    } else {
                        echo '<div class="wst-loader-'.$pr_ld.'">';
                            if( $pr_ld == '2' ){
                                echo '<div id="spinningSquaresG">
                                    <div id="spinningSquaresG_1" class="spinningSquaresG"></div>
                                    <div id="spinningSquaresG_2" class="spinningSquaresG"></div>
                                    <div id="spinningSquaresG_3" class="spinningSquaresG"></div>
                                    <div id="spinningSquaresG_4" class="spinningSquaresG"></div>
                                    <div id="spinningSquaresG_5" class="spinningSquaresG"></div>
                                    <div id="spinningSquaresG_6" class="spinningSquaresG"></div>
                                    <div id="spinningSquaresG_7" class="spinningSquaresG"></div>
                                    <div id="spinningSquaresG_8" class="spinningSquaresG"></div>
                                </div>';
                            } else if( $pr_ld == '3' ) {
                                echo '<div class="cssload-contain"><div class="cssload-dot"></div><div class="cssload-dot"></div><div class="cssload-dot"></div><div class="cssload-dot"></div><div class="cssload-dot"></div></div>';
                            }
                        echo '</div>';
                    }
                    
                    if( $loadtxt ){
                        echo '<div class="wst-loader-text">' . esc_html( $loadtxt ) . '</div>';
                    }
                    
                echo '</div>';
            echo '</div>';
            
        }
        
    }    
}

// Site Logo..
if ( ! function_exists( 'wst_header_logo' ) ) {
    function wst_header_logo () {
        global $post;
        $cst_stic_log_src   = '';
        $logo_type          = wst_theme_option( "logo_type" );
        $def_logo           = ( get_post_meta(wst_page_id(), 'meta_logo_img', true ) == '' )        ? wst_theme_option( "header_logo_image" )   : get_post_meta(wst_page_id(), 'meta_logo_img', true );
        $ret_logo           = ( get_post_meta(wst_page_id(), 'meta_retina_logo_img', true ) == '' ) ? wst_theme_option( "retina_logo_image" )   : get_post_meta(wst_page_id(), 'meta_retina_logo_img', true );
        
        if( is_404() ){
            $ret_logo       = ( wst_theme_option( 'retinalogo404' ) != '' ) ? wst_theme_option( 'retinalogo404' )   : $ret_logo;
            $def_logo       = ( wst_theme_option( 'logo404' ) != '' )       ? wst_theme_option( 'logo404' )         : $def_logo;
        }

        $class              = 'wst_logo';
        $class             .= ( $logo_type == 'image' ) ? ' wst-logo-img' : '';
        
        $stk_logo           = ( get_post_meta(wst_page_id(), 'meta_sticky_logo_img', true ) == '' ) ? wst_theme_option( "sticky_logo" )         : get_post_meta(wst_page_id(), 'meta_sticky_logo_img', true );
        $log_id             = preg_replace( '/[^\d]/', '', $def_logo );
        $log_src            = wp_get_attachment_image_src( $log_id,'full' );
        $ret_id             = preg_replace( '/[^\d]/', '', $ret_logo );
        $ret_src            = wp_get_attachment_image_src( $ret_id,'full' );
        $sitck_log_id       = preg_replace( '/[^\d]/', '', $stk_logo );
        $sitck_log_src      = wp_get_attachment_image_src( $sitck_log_id,'full' );        
        $logo               = ( $log_src ) ? $log_src[0] : '';
        $stic               = ( $sitck_log_src ) ? $sitck_log_src[0] : '';
        $reti               = ( $ret_src != '' )                    ? $ret_src[0]                           : '';
        $dstic              = ( $stic != '' && $stic != $logo )     ? " data-sticky=".esc_url($stic)        : '';
        $dorg               = ( $stic != '' && $stic != $logo )     ? " data-orig-logo=".esc_url($logo)     : ''; 
        $dret               = ( $reti != '' )                       ? ' srcset='.$reti                      : '';
        $logo_atts          = [];
        $logo_atts[]        = ( $stic != '' && $stic != $logo ) ? 'data-sticky="' . esc_url($stic) . '" data-orig-logo="' . esc_url($logo) . '"' : '';
        $logo_atts[]        = ( $reti != '' ) ? 'data-retina="' . esc_url($reti) . '" srcset="' . esc_url($reti) . ' 2x"' : ''; ?>

        <div class="<?php echo esc_attr( $class ); ?>">
            <?php if( $logo_type == 'image' ){ ?>
                <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
                    <img alt="<?php bloginfo( 'name' ); ?>" class="site_logo" src="<?php echo esc_url($logo); ?>" <?php echo implode( " ", $logo_atts ) ?>>
                </a>
            <?php } else { ?>
                <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">     
                    <i class="logo-txt"><?php bloginfo( 'name' ); ?></i>
                    <span class="tagline"><?php bloginfo('description'); ?></span>
                </a>
           <?php } ?>
        </div>
        <?php
    }
}

// Theme Header..
if ( ! function_exists( 'wst_header' ) ){
    function wst_header(){
        
        $hide_header    = get_post_meta( wst_page_id() , 'meta_hide_header'         , true );
        $meta_header    = get_post_meta( wst_page_id() , 'meta_header_style'        , true );
        $meta_layout    = get_post_meta( wst_page_id() , 'meta_main_layout'         , true );
        $meta_invis     = get_post_meta( wst_page_id() , 'meta_header_invisible'    , true );
        $meta_dir       = get_post_meta( wst_page_id() , 'meta_side_dir'            , true );
        $meta_particles = get_post_meta(wst_page_id()  , 'meta_page_particles'      ,true);
        $them_particles = wst_theme_option( 'theme_particles' );
        $theme_header   = wst_theme_option( 'header_style' );
        $invis          = wst_theme_option( 'head_visible' );
        $dir            = ( $meta_dir       == '' )     ? wst_theme_option('side_dir')  : $meta_dir;
        $hedinvis       = ( $meta_invis     == '' )     ? $invis                        : $meta_invis;
        $head_style     = ( $meta_header    == '' )     ? $theme_header                 : $meta_header;
        $partcls        = ( $meta_particles == '' )     ? $them_particles               : $meta_particles;
        $mob_menu       = wst_theme_option( 'mobile-menu' );

        $class          = 'pageWrapper';
        $class         .= ( $head_style    == 'side' && $hedinvis == '1' ) ? ' invis_header'       : '';
        $class         .= ( $head_style     == 'side' )                     ? ' side-wrap ' .$dir   : '';
        $class         .= ( $mob_menu )                                     ? ' wst-has-mobile-menu' : '';
        $class         .= ( isset( $meta_layout ) && $meta_layout != '' )   ? ' '.$meta_layout      : ' '.wst_theme_option( 'layout' );
        $class         .= ( get_post_meta( wst_page_id(), 'meta_fullscreen_onepage' , true) == 1 ) ? ' wst-fullscreen-page' : '';            
                
        echo '<div class="'. esc_attr( $class ) .'">';

            if ( $partcls == '1' ) {
                echo '<div class="wst-grid-particles">
                    <div class="container">
                        <div class="row">
                        <div class="col-md-2 wst-grid-line">
                            <div class="wst-enlax" data-enllax-type="foreground" data-enllax-ratio="-0.3"></div>
                        </div>
                        <div class="col-md-2 wst-grid-line">
                            <div class="wst-enlax enl-sm" data-enllax-type="foreground" data-enllax-ratio="-0.5"></div>
                        </div>
                        <div class="col-md-2 wst-grid-line">
                            <div class="wst-enlax" data-enllax-type="foreground" data-enllax-ratio="-0.2"></div>
                        </div>
                        <div class="col-md-2 wst-grid-line">
                            <div class="wst-enlax enl-lg" data-enllax-type="foreground" data-enllax-ratio="-0.7"></div>
                        </div>
                        <div class="col-md-2 wst-grid-line">
                            <div class="wst-enlax enl-sm" data-enllax-type="foreground" data-enllax-ratio="-0.1"></div>
                        </div>
                        <div class="col-md-2 wst-grid-line">
                            <div class="wst-enlax" data-enllax-type="foreground" data-enllax-ratio="-0.4"></div>
                        </div>
                        </div>
                    </div>
                </div>';
            }
                    
            if ( !$hide_header == '1' ){
                get_template_part( 'layout/headers/'.$head_style );
            }

    }
}

// Theme Footer..
if ( ! function_exists( 'wst_footer' ) ){
    function wst_footer(){
        $hide_footer    = get_post_meta( wst_page_id(), 'meta_hide_footer',true);
        $meta_search    = get_post_meta(wst_page_id(),'meta_hide_search',true);
        $meta_header    = get_post_meta(wst_page_id(), 'meta_header_style',true);
        $theme_header   = wst_theme_option('header_style');
        $srch           = ( $meta_search != '' ) ? $meta_search : wst_theme_option("show_search");
        $pg_foot_style  = get_post_meta( wst_page_id(), 'meta_footer_style' , true);
        $thm_foot_style = wst_theme_option('footer_style');
        $foot_style     = ($pg_foot_style != '') ? $pg_foot_style : $thm_foot_style;
        $head           = ( $meta_header != '' ) ? $meta_header : $theme_header;
                
        echo '</div>';
        
        if ( is_singular() && class_exists( 'qonspt_Core' ) ) {
            echo '<span class="ino_url hidden">'.esc_url(content_url()).'</span>';
        }
        if ( $hide_footer == '' ){
            get_template_part( 'layout/footers/footer-'.$foot_style );
        }
        if( wst_theme_option('show_top') == 1 ){
            echo '<a id="to-top" href="#" class="main-bg rounded"><span><i class="stline-arrow-up"></i><i class="stline-arrow-up btn_back"></i></span></a>';
        }
        
        echo '</div>';
        echo '<div class="wst_overlay main-bg"></div>';
        wst_sliding_bar();
        if( $srch == '1' && $head != 'side' ){
            echo '<div class="search-wrapper">';
                echo '<span class="close_search"><i class="stline-close"></i></span>';
                echo get_search_form();
            echo '</div>';
        }
        
    }
}

// get ID by slug
if ( ! function_exists( 'wst_get_id_by_slug' ) ) {
    function wst_get_id_by_slug($page_slug) {
        $page = get_page_by_path($page_slug);
        if ($page) {
            return $page->ID;
        } else {
            return null;
        }
    }
}

// Custom Page Title..
if ( ! function_exists( 'wst_custom_page_title' ) ){
    function wst_custom_page_title() {
        global $post;
        $post_type = get_post_type();
        $post_type_slug = '';
        if ( $post_type ) {
            $post_type_data = get_post_type_object( $post_type );
            $post_type_slug = ( is_array($post_type_data->rewrite) ) ? $post_type_data->rewrite['slug'] : '';
        }
        $page_title = '';
        if(is_front_page() && !is_home() ){
            
            $page_title .= esc_html('Home Page','qonspt');
            
        } else if(is_front_page() && is_home() ){
            
            $page_title = esc_html('Blog Posts','qonspt');
            
        } else if( is_home() ) {
            
            $page_title = get_the_title(get_option('page_for_posts', true));
            
        } else if ( is_search() ) {
    
            $page_title .= get_search_query();
            
        } else if ( is_author() ){
            
            $page_title .= wst_author_title();
            
        } else if ( is_tag() ) {
            
            $page_title .= single_tag_title( '', false );
            
        } else if( is_archive() ) {
            
            if ( is_day() ) {
                $page_title .= get_the_date( _x( 'j F Y', 'yearly archives', 'qonspt' ) );
            } elseif ( is_month() ) {
                $page_title .= get_the_date( _x( 'F Y', 'yearly archives', 'qonspt' ) );
            } elseif ( is_year() ) {
                $page_title .= get_the_date( _x( 'Y', 'yearly archives', 'qonspt' ) );
            } else if( class_exists( 'Woocommerce' ) && is_woocommerce() && ( is_product() || is_shop() ) && ! is_search() ) {
                $page_title = woocommerce_page_title( false );
            } else if(class_exists( 'Woocommerce' ) && is_product_category()){
                $page_title = single_cat_title('', false);
            } else if ( 'post' == get_post_type() ) {
                $page_title = single_cat_title('', false);
            } else if ( $post_type_slug == get_post_type() ) {
                $page_title = single_cat_title('', false);
            } else {
                $page_title = get_the_title();
            }
            
        } else if( class_exists( 'Woocommerce' ) && is_woocommerce() && ( is_shop() ) && ! is_search() ) {
            
            if( ! is_product() ) {
                $page_title = woocommerce_page_title( false );
            }
            
        } else {
            
            $page_title = get_the_title();
            
        }

        return $page_title;
    }
}

// Custom Page Sub Title..
if ( ! function_exists( 'wst_custom_page_subtitle' ) ){
    function wst_custom_page_subtitle() {
        global $post,$wp_query;
        $subtitl_text = '';
        if ( is_search() ) {
    
            $subtitl_text .= '<span class="wst-found-posts">'.esc_attr( $wp_query->found_posts ). '</span> ' .esc_html__( 'Search results found', 'qonspt' );
            
        } else if ( is_author() ){
            
            $subtitl_text .= '';
            
        } else if ( is_tag() ) {
                        
            if(tag_description()){
                $subtitl_text .= tag_description( $tag_id );
            }
            
        } else if( is_archive() ) {
            
            if(category_description()){
                $subtitl_text .= category_description();
            }
            
        }

        return $subtitl_text;
    }
}

// Custom Page Title Icon..
if ( ! function_exists( 'wst_page_title_icon' ) ){
    function wst_page_title_icon(){
        
        $title_icon = ( get_post_meta( wst_page_id() , 'meta_title_icon' , true) == '' ) ? wst_theme_option('page_title_icon') : get_post_meta( wst_page_id() , 'meta_title_icon' , true);
        
        if( $title_icon != '' ){
           echo '<i class="title-icon '.$title_icon.'"></i>'; 
        }
        
    }
}

// Site Breadcrumbs..
if ( ! function_exists( 'wst_site_breadcrumbs' ) ) {
    function wst_site_breadcrumbs () {
        
        $br_align           = ( get_post_meta(wst_page_id(),'meta_title_bread_position',true) == '' ) ? wst_theme_option( 'page_title_breadcrumbs_align' ) : get_post_meta(wst_page_id(),'meta_title_bread_position',true);
        $bread_show         = ( get_post_meta(wst_page_id(),'meta_hide_breadcrumbs',true) == '' ) ? wst_theme_option( 'page_title_show_breadcrumbs' ) : get_post_meta(wst_page_id(),'meta_hide_breadcrumbs',true);
        $bread_style        = ( get_post_meta(wst_page_id(),'meta_breadcrumbs_style',true) == '' )? wst_theme_option( 'page_title_breadcrumbs_style' ) : get_post_meta(wst_page_id(),'meta_breadcrumbs_style',true);
        $prefix             = wst_theme_option( 'page_title_breadcrumbs_prefix' );
        $suffix             = wst_theme_option( 'page_title_breadcrumbs_suffix' );
        $bread_mobile       = wst_theme_option( 'page_title_mobile_breadcrumbs' );
        
        if ( $bread_mobile == '' ){
            $mob = ' hidden-xs';    
        } else {
            $mob = '';
        }
        
        if( $bread_show == '1'  ) {
            if (function_exists('yoast_breadcrumb')) {
                $yoast_links_options = get_option('wpseo_internallinks');
                $yoast_bc_enabled = $yoast_links_options['breadcrumbs-enable'];
                if ( $yoast_bc_enabled) {
                    yoast_breadcrumb('<div id="breadcrumbs" class="breadcrumb'.esc_attr($mob).' '.esc_attr($br_align).' '.esc_attr($bread_style).'"><div class="container">','</div></div>');
                }
            } else if(function_exists('bcn_display')) {
                echo '<div class="breadcrumb'.esc_attr($mob).' '.esc_attr($br_align).' '.esc_attr($bread_style).'">';
                
                if( $bread_style == 'style1' ) echo '<div class="container">';
                
                if($prefix) echo '<span>'.esc_html($prefix).'</span> '; 
                bcn_display();
                if($suffix) echo '<span>'.esc_html($suffix).'</span> ';
                
                if( $bread_style == 'style1' ) echo '</div>';
                
                echo '</div>';
            }    
        }    
    }
}

// If visual composer plugin is active functions..
if ( ! function_exists( 'wst_vc_active' ) ) {
    
    function wst_vc_active() {
        if ( class_exists( 'Vc_Manager' ) && defined( 'WPB_VC_VERSION' ) ) { return true; } else { return false; }
    }
    
    if( wst_vc_active() ){
        
        
        if( ! function_exists( 'wst_get_vc_column' ) ) {
            function wst_get_vc_column( $width = '' ) {
                $width = explode('/', $width);
                $width = ( $width[0] != '1' ) ? $width[0] * (12 / $width[1]) : (12 / $width[1]);
                $width = str_replace('.', '-', $width);
                return  'col-md-'.$width;
            }
        }

        if( ! function_exists( 'wst_column_offset_class_merge' ) ) {
            function wst_column_offset_class_merge( $column_offset, $width ) {
                $width = explode('/', $width);
                $width = ( $width[0] != '1' ) ? $width[0] * (12 / $width[1]) : (12 / $width[1]);
                $width = str_replace('.', '-', $width);
                if ( '1' === vc_settings()->get( 'not_responsive_css' ) ) {
                    $column_offset = preg_replace( '/col\-(lg|md|xs)[^\s]*/', '', $column_offset );
                }
                if ( preg_match( '/col\-sm\-\d+/', $column_offset ) ) {
                    return $column_offset;
                }
                return 'col-md-'.$width . ( empty( $column_offset ) ? '' : ' ' . $column_offset );
            }
        }
    }
}

// Forums issue with selected menu item..  
if ( ! function_exists( 'wst_custom_menu_classes' ) ){
   function wst_custom_menu_classes( $classes , $item ){
        global $post;
        if ( is_archive() || ( !is_singular('post') ) || is_tag() || is_404() || is_search() ) {
            $classes = str_replace( 'current_page_parent', '', $classes );
        }
        return $classes;
    }
    add_filter( 'nav_menu_css_class', 'wst_custom_menu_classes', 10, 2 );
}

// Pagination..
if ( ! function_exists( 'wst_paging_nav' ) ) {
    function wst_paging_nav() {
        global $wp_query;
        if ( $wp_query->max_num_pages < 2 ) return;
        $big = 999999999;
        $args = array(
            'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
            'format' => '?paged=%#%',
            'current' => max( 1, get_query_var('paged') ),
            'total' => $wp_query->max_num_pages,
            'type' => 'list',
            'prev_text' => '<i class="fa fa-angle-left"></i>',
            'next_text' => '<i class="fa fa-angle-right"></i>'                    
        );
        
        $pg_pos = wst_theme_option('pager_position');
        $p_type = wst_theme_option('pager_type');
        $lodtxt = (wst_theme_option('load_more_text') != '' ) ? esc_attr(wst_theme_option('load_more_text')) : esc_html__('Load More','qonspt');
        
        if ( $p_type == "1" ) { ?>
            <div class="pager <?php echo esc_attr($pg_pos);?>">
                <?php echo paginate_links( $args ); ?>
            </div>
        <?php } else if ( $p_type == "2" ) { ?>
            <ul class="pager oldnew">
                <li class="previous"><?php next_posts_link('<span><i class="fa fa-angle-left main-color"></i></span> '.esc_html__('OLDER ENTIRES', 'qonspt')) ?></li>
                <li class="next"><?php previous_posts_link(esc_html__('NEWER ENTIRES', 'qonspt'). ' <span><i class="fa fa-angle-right main-color"></i></span>') ?></li>
            </ul>
        <?php } else if ( $p_type == "3" ){
            $perm = ( get_option('permalink_structure') ) ? '/page/' : '&paged='; ?>
             <div class="loadmore">
                <span class="hidden blgurl" data-pag="<?php echo esc_attr($perm); ?>"><?php echo esc_url(wst_get_post_page_url()); ?></span>
                <a href="#" class="btn bold btn-lg btn-hover-shad"><?php echo esc_attr($lodtxt); ?> <span class="wst_preloader"><i class="main-color stline-loading-2"></i></span></a>
                <div class="hidden pgnum"><?php echo esc_attr($wp_query->max_num_pages) ?></div>
                <div class="load_msg"><?php echo esc_html__('No More Posts To Show !!', 'qonspt') ?></div>
            </div>
        <?php }
    }
}

if ( ! function_exists( 'wst_get_post_page_url' ) ) {
    function wst_get_post_page_url() {
        if( 'page' == get_option( 'show_on_front' ) ) {
            return get_permalink( get_option('page_for_posts' ) );
        } else {
            return home_url();
        }
    }
}

// if wpml is activated..
if ( ! function_exists( 'wst_wpml_activated' ) ) {
    function wst_wpml_activated() {
        if ( class_exists( 'SitePress' ) ) { return true; } else { return false; }
    }
}

// WPML plugin..
if ( class_exists( 'SitePress' ) ) {
   define('ICL_DONT_LOAD_LANGUAGE_SELECTOR_CSS', true); 
}

// Get current user..
if ( ! function_exists('wst_get_user_name') ){
    function wst_get_user_name(){
        $current_user   = wp_get_current_user();
        $firstname      = $current_user->user_firstname;
        $lastname       = $current_user->user_lastname;
        $a_nicename     = $current_user->user_nicename;
        $loginname      = $current_user->user_login;
        $author_id      = $current_user->user_id;
        $user_name      = $loginname;
        if(isset($firstname) && !empty($firstname)) {
            $user_name = $firstname . ' ' . $lastname;
        }
        if ( class_exists( 'woocommerce' ) ){
            return ' <a class="bold" href="'.esc_url(get_permalink( get_option('woocommerce_myaccount_page_id') )).'">' . $user_name . '</a>';    
        } else {
            return ' <a class="bold" href="'.esc_url(get_author_posts_url( $author_id, $a_nicename )).'">' . $user_name . '</a>';    
        }
    }
}

if ( ! function_exists('wst_author_title') ){
    function wst_author_title(){
        $current_user   = wp_get_current_user();
        $firstname      = $current_user->user_firstname;
        $lastname       = $current_user->user_lastname;
        $loginname      = $current_user->user_login;
        $user_name      = $loginname;
        if(isset($firstname) && !empty($firstname)) {
            $user_name = $firstname . ' ' . $lastname;
        }
        return $user_name;
    }
}

if ( ! function_exists('wst_login_form') ){
    function wst_login_form( $args = array() ){
        
        $defaults = array(
            'echo' => true,
            'form_id' => 'loginform',
            'remember' => true,
            'value_remember' => true,
        );
        $args           = wp_parse_args( $args, apply_filters( 'login_form_defaults', $defaults ) );
        $form_id        = uniqid('loginform_');
        $user_id        = uniqid('user_login_');
        $pass_id        = uniqid('user_pass_');
        $remember_id    = uniqid('rememberme_');
        $submit_id      = uniqid('wp-submit_');

        echo '<form class="wid_login_form" name="' . esc_attr( $form_id ) . '" id="' . esc_attr( $form_id ) . '" action="' . esc_url( site_url( 'wp-login.php', 'login_post' ) ) . '" method="post">';
            
            echo '<div class="form-group">';
                echo '<label for="' . esc_attr( $user_id ) . '" class="form-label">' . esc_html__( 'Username or Email Address', 'qonspt' ) . '</label>';
                echo '<input type="text" name="log" id="' . esc_attr( $user_id ) . '" class="form-control" size="20" />';
            echo '</div>';
            
            echo '<div class="form-group">';
                echo '<label for="' . esc_attr( $pass_id ) . '" class="form-label">' . esc_html__( 'Password', 'qonspt' ) . '</label>';
                echo '<input type="password" name="pwd" id="' . esc_attr( $pass_id ) . '" class="form-control" size="20" />';
            echo '</div>';
            
            echo '<div class="form-group wst-login-links">';
                echo '<div class="wst-login-lft">';
                    echo '<button type="submit" name="wp-submit" id="' . esc_attr( $submit_id ) . '" class="btn btn-login btn-hover-shad main-bg">' .esc_html__( 'LOGIN', 'qonspt' ). '</button>';
                echo '</div>';
                
                echo '<div class="wst-login-rit">';
                    echo '<div><input name="rememberme" type="checkbox" id="' . esc_attr( $remember_id ) . '" value="'. esc_attr( $args['value_remember'] ) .'" /> ' . esc_html__( 'Remember me!','qonspt' ) . '</div>';
                    echo '<div><a href="' . esc_url( wp_lostpassword_url() ) . '" class="main-color">' . esc_html__( 'Lost your password ?','qonspt' ) . '</a></div>';
                echo '</div>';
                
            echo '</div>';
                                    
            if ( get_option( 'users_can_register' ) ) {
                echo '<div>';
                    echo '<span>'. esc_html__("Don't have an account?", 'qonspt') .'</span> ';
                    echo '<a href="'. esc_url( wp_registration_url() ) .'" class="main-color">'. esc_html__('Sign up Now', 'qonspt') .'</a>';
                echo '</div>';
            }
             
        echo '</form>';
        
    }
}

// Sliding bar function..
if ( ! function_exists('wst_sliding_bar') ){
    function wst_sliding_bar() {
        $langcode = '';
        if ( class_exists( 'SitePress' ) ) {
            $langcode = '-'.ICL_LANGUAGE_CODE;
        } else if( class_exists( 'Polylang' ) ){
            $langcode = '-'. pll_current_language();
        }
        
        $meta_header          = get_post_meta( wst_page_id() , 'meta_header_style' , true );
        $theme_header         = wst_theme_option( 'header_style' );
        $head_style           = ( $meta_header == '' ) ? $theme_header : $meta_header;
        $show_sliding_bar     = wst_theme_option('show_sliding_bar');
        $sbar_cols            = wst_theme_option('sliding_bar_columns');
        $sbar_top_border      = wst_theme_option('top_border_on_sliding_bar');
        $sbar_btn_pos         = wst_theme_option('btn_position'); 
        $sbar_frst            = wst_theme_option('sliding_first_grad');
        $sbar_scnd            = wst_theme_option('sliding_second_grad');
        $sb                   = wst_theme_option('sliding_bar_sidebar'.$langcode); 
        $class                = 'slbar columns-'.$sbar_cols;
        
        if($sbar_top_border == '1'){
            $class .= ' sl_tp_border';
        }

        $grd        = esc_textarea( $sbar_frst );
        $on         = strstr($grd, '#');
        $fist_hx    = substr($on, 0, 7);
        $str2       = substr($on, 7);
        $needle     = strstr($str2, '#'); 
        $sec_hx     = substr($needle, 0, 7);

        $grd2        = esc_textarea( $sbar_scnd );
        $on2         = strstr($grd2, '#');
        $fist_hx2    = substr($on2, 0, 7);
        $str2       = substr($on2, 7);
        $needle2     = strstr($str2, '#'); 
        $sec_hx2     = substr($needle2, 0, 7);
                
        if ( $show_sliding_bar == "1" && $head_style != 'side' ) { 
        wp_enqueue_script( 'wst-slbar', wst_thm_uri . '/assets/js/vendor/slidingbar.js', array('jquery'), null, true );
        ?>
        <div class="<?php echo esc_attr($class); ?>">
            <a href="#" class="slbar_close stline-close"></a>
            <div class="sl_bar_content container">
                <?php dynamic_sidebar( $sb ); ?>
            </div>
            <svg class="wst-slbar-over" viewBox="0 0 100 100" preserveAspectRatio="none">
                <defs>
                    <linearGradient id="slbar-grad1" x1="0%" y1="0%" x2="0%" y2="100%">
                        <stop offset="0%"   stop-color="<?php echo esc_attr($fist_hx); ?>"/>
                        <stop offset="100%" stop-color="<?php echo esc_attr($sec_hx); ?>"/>
                    </linearGradient>
                    <linearGradient id="slbar-grad2" x1="0%" y1="0%" x2="0%" y2="100%">
                        <stop offset="0%"   stop-color="<?php echo esc_attr($fist_hx2); ?>"/>
                        <stop offset="100%" stop-color="<?php echo esc_attr($sec_hx2); ?>"/>
                    </linearGradient>
                    <linearGradient id="slbar-grad3" x1="0%" y1="0%" x2="0%" y2="100%">
                        <stop offset="0%"   stop-color="<?php echo wst_theme_option('sliding_bg_color'); ?>"/>
                        <stop offset="100%" stop-color="<?php echo wst_theme_option('sliding_bg_bot_color'); ?>"/>
                    </linearGradient>
                </defs>
                <path class="wst-slbar-over-path" d=""></path>
                <path class="wst-slbar-over-path" d=""></path>
                <path class="wst-slbar-over-path" d=""></path>
            </svg> 
        </div>
        <?php
        } 
    }
}

// Get site menus..
if ( ! function_exists('wst_header_menu') ){
    function wst_header_menu(){
        $page_men   = get_post_meta(wst_page_id(), 'meta_page_menu' , true);        
        $menu       = ( $page_men != '' ) ? $page_men : 'main-menu';
        $mob_menu   = wst_theme_option( 'mobile-menu' );
        $wst_custom_menu = new wst_custom_menu();
        if ( has_nav_menu( $menu ) ) {
            echo '<a href="#" class="wst-responsive-btn"><i class="stline-navigation-menu-vertical"></i></a>';
            if( $mob_menu ){
                echo '<div class="wst-mobile-navigation">';
                $wst_custom_menu->wst_nav_menu( [
                    'menu'           => $mob_menu,
                    'theme_location' => $menu
                ] );
                echo '</div>';
            }

            $wst_custom_menu->wst_nav_menu( array( 'theme_location' => $menu) ); 
        } else {
            echo '<span class="menu-message">'.esc_html__('Please go to admin panel > Menus > select the menu and add items to it.', 'qonspt').'</span>';
        }

    }
}

// Custom Header menus..
if ( ! function_exists('wst_choose_header_menu') ){
    function wst_choose_header_menu($area){                                                                             
        $page_men = ( get_post_meta(wst_page_id(), 'meta_header_'.$area.'_area_menu', true) == '' ) ? wst_theme_option( 'header_'.$area.'_area_menu' ) : get_post_meta(wst_page_id(), 'meta_header_'.$area.'_area_menu', true);
                
        $menu = ( $page_men ) ? $page_men : 'main-menu';
        
        if ( has_nav_menu( $menu ) ) {
            echo '<a href="#" class="wst-responsive-btn"><i class="stline-navigation-menu-vertical"></i></a>';
            $wst_custom_menu = new wst_custom_menu();
            $wst_custom_menu->wst_nav_menu( array( 'theme_location' => $menu) ); 
        }else{
            echo '<span class="menu-message">'.esc_html__('Please go to admin panel > Menus > select the menu and add items to it.', 'qonspt').'</span>';
        }
    }
}

if ( ! function_exists('wst_header_icons') ){
    function wst_header_icons(){
        
        $meta_search    = get_post_meta(wst_page_id(),'meta_hide_search',true);
        $meta_cart      = get_post_meta(wst_page_id(),'meta_hide_cart',true);
        $meta_slbar     = get_post_meta(wst_page_id(),'meta_hide_slbar',true);
        $srch           = ( $meta_search != '' )    ? $meta_search  : wst_theme_option("show_search");
        $cart           = ( $meta_cart != '' )      ? $meta_cart    : wst_theme_option("show_cart");
        $slbar          = ( $meta_slbar != '' )     ? $meta_slbar   : wst_theme_option("show_sliding_bar");
        
        if( $srch == '1' || $slbar == '1' || $cart == '1' ){ ?>
            <div class="wst-head-btns">
                
                <?php if( $srch == '1' ) { ?>
                    <div class="head-btn">
                        <a href="#" class="open_search stline-search"></a>
                    </div>
                <?php } ?>
                
                <?php if ( class_exists( 'woocommerce' ) && $cart  == '1' ) { ?>
                    <div class="head-btn cart-btn">
                        <?php echo wst_woo_cart(); ?>
                    </div>
                <?php } ?>
                
                <?php if ( $slbar == '1' ) { ?>
                    <div class="head-btn">
                        <a href="#" class="slbar_btn stline-navigation-menu"></a>
                    </div>
                <?php } ?>
                
            </div>
        <?php }
        
    }
}

if ( ! function_exists( 'wst_header_button' ) ){
    function wst_header_button ($area){
        
        $meta_shortcode = get_post_meta(wst_page_id(),'meta_header_'.$area.'_shortcode',true);
        $head_shortcode = ( $meta_shortcode == '' ) ? wst_theme_option('header_'.$area.'_shortcode') : $meta_shortcode;
        
        echo '<div class="wst-head-btn wst-head-btn-'.$area.'">' . do_shortcode($head_shortcode) . '</div>';
    }
}

 if ( ! function_exists('wst_side_head_bottom') ){
    function wst_side_head_bottom(){
        
        
        
    }
}

// Theme page title style..
if ( ! function_exists( 'wst_title_style' ) ){
    function wst_title_style(){
        if ( !is_404() ){
            $h_title = get_post_meta(wst_page_id(),'hide_page_title',true);
            if( $h_title != '1' ) {
                get_template_part( 'layout/headers/page-title');
            }
        }
    }
}

// Limit number of tags inside widget..
if ( ! function_exists( 'wst_tag_widget_limit' ) ){
    function wst_tag_widget_limit($args){
        $tagsNo = wst_theme_option('tags_limit');
         if(isset($args['taxonomy']) && $args['taxonomy'] == 'post_tag'){
          $args['number'] = esc_attr($tagsNo);
         }

         return $args;
    }
    add_filter('widget_tag_cloud_args', 'wst_tag_widget_limit');
}

// Allowed tags..
if ( ! function_exists( 'wst_allowed_tags' ) ){
    function wst_allowed_tags(){
        global $allowedtags;
        
        $attrs = array(
            'style'                 => array(),
            'id'                    => array(),
            'src'                   => array(),
            'alt'                   => array(),
            'title'                 => array(),
            'data-toggle'           => array(),
            'data-trigger'          => array(),
            'data-placement'        => array(),
            'data-content'          => array(),
            'data-original-title'   => array(),
            'href'                  => array(),
            'class'                 => array(),
        );
        
        $allowedtags['span']    = $attrs;
        $allowedtags['div']     = $attrs;
        $allowedtags['p']       = $attrs;
        $allowedtags['img']     = $attrs;
        $allowedtags['b']       = $attrs;
        $allowedtags['i']       = $attrs;
        $allowedtags['strong']  = $attrs;
        $allowedtags['a']       = $attrs;
        $allowedtags['u']       = $attrs;
        
        return $allowedtags;
    }
}

// Social icons..
if ( ! function_exists( 'wst_display_social_icons' ) ) {
    function wst_display_social_icons(){
        
        $soc            = wst_theme_option('social_icons');
        $nofollow       = wst_theme_option('socials_nofollow');
        $newwindow      = wst_theme_option('socials_new_window');
        $rel            = ( $nofollow ) ? ' rel="nofollow"' : '';
        $target         = ( $newwindow ) ? ' target="_blank"' : '';
        
        $output         = '<div class="social-list">';
        
            for ( $i = 1; $i <= $soc ; $i++ ) {
                
                $ico = wst_theme_option( "social_icon_" . $i );
                $lnk = wst_theme_option( "social_icon_link_" . $i );
                
                if ( $ico ) { 
                    $output .= "<a href='". esc_url( $lnk ) ."'{$rel}{$target}><i class='{$ico}'></i><i class='{$ico}'></i></a>";
                }
            }
        
        $output .='</div>'; 
           
        return $output;    
    }    
}

if ( ! function_exists( 'wst_remove_contact_wrapper' ) ) {
    function wst_remove_contact_wrapper($content) {
        $content = preg_replace('/<(span).*?class="\s*(?:.*\s)?wpcf7-form-control-wrap(?:\s[^"]+)?\s*"[^\>]*>(.*)<\/\1>/i', '\2', $content);
        return $content;
    }
    add_filter('wpcf7_form_elements', 'wst_remove_contact_wrapper');
}

// Fix tags issue in custom post types..
if ( ! function_exists( 'wst_fix_tags' ) ) {
    function wst_fix_tags( $query ) {
        if( is_tag() && $query->is_main_query() ) {
            $post_types = get_post_types();
            $query->set( 'post_type', $post_types );
        }
    }
    add_filter( 'pre_get_posts', 'wst_fix_tags' );    
}

if ( ! function_exists( 'wst_allow_data_event_content' ) ) {
    function wst_allow_data_event_content() {
        global $allowedposttags, $allowedtags;
        $newattribute                           = "style"; 
        $allowedposttags["span"][$newattribute] = true;
        $allowedtags["span"][$newattribute]     = true;
        $allowedposttags["ul"][$newattribute]   = true;
        $allowedtags["ul"][$newattribute]       = true;
        $allowedposttags["li"][$newattribute]   = true;
        $allowedtags["li"][$newattribute]       = true;
    }
    add_action( 'init', 'wst_allow_data_event_content' );
}

if ( ! function_exists( 'wst_them_url_dash' ) ) {
    function wst_them_url_dash(){
        
        echo '<span class="hidden adm">'.esc_url(admin_url()).'</span>';
        echo '<span class="hidden themeURI">'.wst_thm_uri.'</span>';
        
    } 
    add_action('admin_footer', 'wst_them_url_dash');   
}

if ( ! function_exists( 'wst_sidebars_arr' ) ) {
    function wst_sidebars_arr() {
        global $wp_registered_sidebars;
        $sbars = array();
        foreach($wp_registered_sidebars as $sidebar_id => $sidebar){
            $sbars[$sidebar_id] = $sidebar['name'];
        }
        return $sbars;
    }
}

if ( ! function_exists( 'wst_dynamic_sidebar' ) ) {
    function wst_dynamic_sidebar($index = 1) {
        $sidebar_contents = "";
        ob_start();
        dynamic_sidebar($index);
        $sidebar_contents = ob_get_clean();
        return $sidebar_contents;
    }    
}

// Color creator functions..
if ( ! function_exists( 'wst_colourCreator' ) ) {
    function wst_colourCreator($colour, $per) {  
        $colour = substr( $colour, 1 ); // Removes first character of hex string (#) 
        $rgb = ''; // Empty variable 
        $per = $per/100*255; // Creates a percentage to work with. Change the middle figure to control colour temperature
         
        if  ($per < 0 ) // Check to see if the percentage is a negative number 
        { 
            // DARKER 
            $per =  abs($per); // Turns Neg Number to Pos Number 
            for ($x=0;$x<3;$x++) 
            { 
                $c = hexdec(substr($colour,(2*$x),2)) - $per; 
                $c = ($c < 0) ? 0 : dechex($c); 
                $rgb .= (strlen($c) < 2) ? '0'.$c : $c; 
            }   
        }  
        else 
        { 
            // LIGHTER         
            for ($x=0;$x<3;$x++) 
            {             
                $c = hexdec(substr($colour,(2*$x),2)) + $per; 
                $c = ($c > 255) ? 'ff' : dechex($c); 
                $rgb .= (strlen($c) < 2) ? '0'.$c : $c; 
            }    
        } 
        return '#'.$rgb; 
    }    
}

if ( ! function_exists( 'wst_hex_to_rgb' ) ) {
    function wst_hex_to_rgb($hexStr, $returnAsString = false, $seperator = ',') {
        $hexStr = preg_replace("/[^0-9A-Fa-f]/", '', $hexStr); // Gets a proper hex string
        $rgbArray = array();
        if (strlen($hexStr) == 6) { //If a proper hex code, convert using bitwise operation. No overhead... faster
            $colorVal = hexdec($hexStr);
            $rgbArray['red'] = 0xFF & ($colorVal >> 0x10);
            $rgbArray['green'] = 0xFF & ($colorVal >> 0x8);
            $rgbArray['blue'] = 0xFF & $colorVal;
        } elseif (strlen($hexStr) == 3) { //if shorthand notation, need some string manipulations
            $rgbArray['red'] = hexdec(str_repeat(substr($hexStr, 0, 1), 2));
            $rgbArray['green'] = hexdec(str_repeat(substr($hexStr, 1, 1), 2));
            $rgbArray['blue'] = hexdec(str_repeat(substr($hexStr, 2, 1), 2));
        } else {
            return false; //Invalid hex color code
        }
        return $returnAsString ? implode($seperator, $rgbArray) : $rgbArray; // returns the rgb string or the associative array
    }
}

if ( ! function_exists( 'wst_color_brightness' ) ){
    function wst_color_brightness($hex, $percent) {
        $hash = '';
        if (stristr($hex,'#')) {
            $hex = str_replace('#','',$hex);
            $hash = '#';
        }
        $rgb = array(hexdec(substr($hex,0,2)), hexdec(substr($hex,2,2)), hexdec(substr($hex,4,2)));
        for ($i=0; $i<3; $i++) {
            if ($percent > 0) {
                // Lighter
                $rgb[$i] = round($rgb[$i] * $percent) + round(255 * (1-$percent));
            } else {
                // Darker
                $positivePercent = $percent - ($percent*2);
                $rgb[$i] = round($rgb[$i] * $positivePercent) + round(0 * (1-$positivePercent));
            }
            if ($rgb[$i] > 255) {
                $rgb[$i] = 255;
            }
        }
        $hex = '';
        for($i=0; $i < 3; $i++) {
            $hexDigit = dechex($rgb[$i]);
            if(strlen($hexDigit) == 1) {
            $hexDigit = "0" . $hexDigit;
            }
            $hex .= $hexDigit;
        }
        return $hash.$hex;
    }
}


// Enable custom fonts extensions uploads..
if ( ! function_exists( 'wst_enable_extended_upload' ) ) {
    function wst_enable_extended_upload ( $mime_types =array() ) {
       $mime_types['ttf']   = 'application/font-sfnt';
       $mime_types['eot']   = 'application/vnd.ms-fontobject';
       $mime_types['svg']   = 'image/svg+xml';
       $mime_types['svgz']  = 'image/svg+xml';
       $mime_types['woff']  = 'application/font-woff';
       return $mime_types;
    }
    add_filter('upload_mimes', 'wst_enable_extended_upload');    
}