<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.4.0
 * @author     Thomas Griffin <thomasgriffinmedia.com>
 * @author     Gary Jones <gamajo.com>
 * @copyright  Copyright (c) 2014, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */

require get_parent_theme_file_path('includes/plugins/plugins/class-tgm-plugin-activation.php');

function wst_register_required_plugins() {

    $api_url            = 'http://wp.it-rays.net/qonspt/plugins.json';
    $response           = wp_remote_get( $api_url );
    $body               = wp_remote_retrieve_body( $response );
    $result             = json_decode( $body, true );
    $data               = ( $result ) ? $result[ 'plugins' ] : '';
    $qnspt_core_version = ( $data ) ? $data[0][ 'version' ] : '';
    $revslider_version  = ( $data ) ? $data[1][ 'version' ] : '';
    $js_comp_version    = ( $data ) ? $data[2][ 'version' ] : '';

    $plugins = array(

        // Visual Composer : Page Builder 
        [
            'name'      => 'Visual Composer : Page Builder',
            'slug'      => 'js_composer',
            'source'    => 'http://wp.it-rays.net/plugins/js_composer.zip',
            'required' => true,
            'version'  => $js_comp_version,
        ],

        // Slider Revolution
        [
            'name'      => 'Slider Revolution',
            'slug'      => 'revslider',
            'source'    => 'http://wp.it-rays.net/plugins/revslider.zip',
            'required'  => false,
            'version'   => $revslider_version,
        ],

        // qonspt Core 
        [
            'name'      => 'qonspt Core',
            'slug'      => 'qonspt-core',
            'source'    => 'http://wp.it-rays.net/plugins/qonspt-core.zip',
            'required'  => true,
            'version'   => $qnspt_core_version,
        ],

        // RAYS Grid 
        [
            'name'      => 'RAYS Grid',
            'slug'      => 'rays-grid',
            'required'  => false,
        ],

        // Contact Form 7
        [
            'name'      => 'Contact Form 7',
            'slug'      => 'contact-form-7',
            'required'  => false,
        ],
        
        // Breadcrumb NavXT
        [
          'name'      => 'Breadcrumb NavXT',
          'slug'      => 'breadcrumb-navxt',
          'required'  => false,
        ],
        
        // MailChimp
        [
          'name'      => 'MailChimp for WordPress',
          'slug'      => 'mailchimp-for-wp',
          'required'  => false,
        ]

    );

    /**
   * Array of configuration settings. Amend each line as needed.
   * If you want the default strings to be available under your own theme domain,
   * leave the strings uncommented.
   * Some of the strings are added into a sprintf, so see the comments at the
   * end of each line for what each argument will be.
   */
    $config = array(
        'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => esc_html__( 'Install Required Plugins', 'qonspt' ),
            'menu_title'                      => esc_html__( 'Install Plugins', 'qonspt' ),
            'installing'                      => esc_html__( 'Installing Plugin: %s', 'qonspt' ), // %s = plugin name.
            'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'qonspt' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'qonspt' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'qonspt' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'qonspt' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'qonspt' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'qonspt' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'qonspt' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'qonspt' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'qonspt' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'qonspt' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'qonspt' ),
            'return'                          => esc_html__( 'Return to Required Plugins Installer', 'qonspt' ),
            'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'qonspt' ),
            'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s', 'qonspt' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

  tgmpa( $plugins, $config );

}

add_action( 'tgmpa_register', 'wst_register_required_plugins' );